ZHitsAtK
========

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ZHitsAtK
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ZHitsAtK.increasing
      ~ZHitsAtK.name
      ~ZHitsAtK.needs_candidates
      ~ZHitsAtK.supported_rank_types
      ~ZHitsAtK.synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: synonyms
